@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 """
 `argparse`-based CLI app using
-`add_argument(choices=shtab.(Optional|Required).(FILE|DIR)`
-for file/directory completion.
+`add_argument().complete = shtab.(FILE|DIR)` for file/dir tab completion.
 
 See `customcomplete.py` for a more advanced version.
 """
@@ -14,17 +13,14 @@ import shtab  # for completion magic
 def get_main_parser():
     parser = argparse.ArgumentParser(prog="pathcomplete")
     parser.add_argument(
-        "-s", "--print-completion-shell", choices=["bash", "zsh"]
-    )
-    parser.add_argument(
-        "--file",
-        choices=shtab.Optional.FILE,  # file tab completion, can be blank
-    )
-    parser.add_argument(
-        "--dir",
-        choices=shtab.Required.DIRECTORY,  # directory tab completion
-        default=".",
+        "-s",
+        "--print-completion-shell",
+        choices=["bash", "zsh"],
+        help="prints completion script",
     )
+    # file & directory tab complete
+    parser.add_argument("file", nargs="?").complete = shtab.FILE
+    parser.add_argument("--dir", default=".").complete = shtab.DIRECTORY
     return parser
 
 
@@ -37,4 +33,4 @@ if __name__ == "__main__":
     if shell:
         print(shtab.complete(parser, shell=shell))
     else:
-        print("received --file='%s' --dir='%s'" % (args.file, args.dir))
+        print("received <file>=%r --dir=%r" % (args.file, args.dir))
